@@ -51,7 +51,10 @@ sub _cass_execute {
     my $conn= $dbh->{cass_connection};
 
     my $values= pack('n', 0+@$params). ($sth->{cass_row_encoder}->(@$params));
-    my $request_body= pack_shortbytes($prepared_id).pack_parameters({ values => $values });
+    my $request_body= pack_shortbytes($prepared_id).pack_parameters({
+        values => $values,
+        consistency => $sth->{cass_consistency},
+    });
 
     my ($opcode, $body)= $conn->request(
         OPCODE_EXECUTE,
